
%global with_zts          0%{?__ztsphp:1}
%global pecl_name         mongodb
%global ini_name          50-%{pecl_name}.ini

%global upstream_version  1.17.2
%global sources           %{pecl_name}-%{upstream_version}%{?upstream_prever}
%global _configure        ../%{sources}/configure

%global bundled_libmongo  1.25.2
%global bundled_libcrypt  1.8.2

%global system_libmongo   1.25.1
%global system_libcrypt   1.8.2

Summary:        MongoDB driver for PHP
Name:           php-pecl-%{pecl_name}
Version:        %{upstream_version}%{?upstream_lower}
Release:    1%{?dist}
License:        Apache-2.0
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{upstream_version}%{?upstream_prever}.tgz

BuildRequires:  gcc
BuildRequires:  php-devel >= 7.4
BuildRequires:  php-pear
BuildRequires:  php-json
BuildRequires:  pkgconfig(libbson-1.0)    >= %{system_libmongo}
BuildRequires:  pkgconfig(libmongoc-1.0)  >= %{system_libmongo}
BuildRequires:  pkgconfig(libmongocrypt)  >= %{system_libcrypt}

Requires:       php(zend-abi) = %{php_zend_api}
Requires:       php(api) = %{php_core_api}
Requires:       php-json

Provides:       php-pecl(%{pecl_name})         = %{version}
Provides:       php-pecl(%{pecl_name}) = %{version}


%description
The purpose of this driver is to provide exceptionally thin glue between
MongoDB and PHP, implementing only fundemental and performance-critical
components necessary to build a fully-functional MongoDB driver.


%prep
%setup -q -c

sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

pushd %{sources}

cat src/*_VERSION_CURRENT
grep -q %{bundled_libmongo} src/LIBMONGOC_VERSION_CURRENT
grep -q %{bundled_libcrypt} src/LIBMONGOCRYPT_VERSION_CURRENT

sed -e 's/%{bundled_libmongo}/%{system_libmongo}/;s/%{bundled_libcrypt}/%{system_libcrypt}/' -i config.m4

extver=$(sed -n '/#define PHP_MONGODB_VERSION /{s/.* "//;s/".*$//;p}' phongo_version.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}"; then
   : Error: Upstream extension version is ${extver}, expecting %{upstream_version}%{?upstream_prever}.
   exit 1
fi

popd

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

cat << 'EOF' | tee %{ini_name}
; Enable %{summary} extension module
extension=%{pecl_name}.so

; Configuration
;mongodb.debug=''
EOF


%build
peclbuild() {

  %configure \
    --with-php-config=%{_bindir}/${1}-config \
    --with-mongodb-system-libs \
    --with-mongodb-client-side-encryption \
    --enable-mongodb

  make %{?_smp_mflags}
}


cd %{sources}
phpize
rm -r src/libmongoc*

cd ../NTS
peclbuild php

%if %{with_zts}
cd ../ZTS
peclbuild zts-php
%endif


%install
make -C NTS \
     install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS \
     install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
OPT="-n"
[ -f %{php_extdir}/json.so ] && OPT="$OPT -d extension=json.so"

cd NTS
: Minimal load test for NTS extension
%{__php} $OPT \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_zts}
cd ../ZTS
: Minimal load test for ZTS extension
%{__ztsphp} $OPT \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}
%endif


%files
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.17.2-1
- initial build
